﻿using System;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Data;

namespace CommandsSample {
   class MainViewModel : NotifyPropertyChanged {

      public static MainViewModel Instance { get; private set; }

      static MainViewModel() { Instance = new MainViewModel(); }

      public ICollectionView Persons { get; private set; }
      private ObservableCollection<Person> _Persons = new ObservableCollection<Person>();

      public RelayCommand cmdCreatePersons { get; private set; }

      public RelayCommand cmdNew { get; private set; }

      public RelayCommand cmdEdit { get; private set; }

      public RelayCommand cmdDelete { get; private set; }

      private MainViewModel() {
         Persons = CollectionViewSource.GetDefaultView(_Persons);
         cmdCreatePersons = new RelayCommand(CreateManyPersons);
         cmdNew = new RelayCommand(CreateNewPerson);
         cmdEdit = new RelayCommand(
            () => new wndPerson(_Persons[Persons.CurrentPosition]).ShowDialog(),
            () => Persons.CurrentPosition >= 0);
         cmdDelete = new RelayCommand(
            () => _Persons.RemoveAt(Persons.CurrentPosition),
            () => Persons.CurrentPosition >= 0);
         CreateManyPersons();
      }

      public void CreateNewPerson() {
         var person = new Person("a Name", "-", DateTime.Now);
         var editor = new wndPerson(person);
         if ((bool)editor.ShowDialog()) {
            _Persons.Add(person);
            Persons.MoveCurrentToPosition(_Persons.Count - 1);
         }
      }

      private void CreateManyPersons() {
         var start = _Persons.Count;
         for (var i = start + 10; i-- > start; ) _Persons.Add(
            new Person("Person" + i, "54321" + i, DateTime.Today.AddYears(-60 + i)));
      }
   }
}
